@@ -23,18 +23,18 @@
 
 // KF headers
 #include <KTextEditor/Document>
-#include <KTextEditor/View>
 #include <KTextEditor/MainWindow>
+#include <KTextEditor/View>
 
 #include <KLocalizedString>
 
-
-%{APPNAME}View::%{APPNAME}View(%{APPNAME}Plugin* plugin, KTextEditor::MainWindow* mainwindow)
+% {APPNAME} View:: %
+    {APPNAME} View(% {APPNAME} Plugin * plugin, KTextEditor::MainWindow *mainwindow)
     : QObject(mainwindow)
 {
     Q_UNUSED(plugin);
 }
 
-%{APPNAME}View::~%{APPNAME}View()
+% {APPNAME} View::~ % {APPNAME} View()
 {
 }
